from httpmessageprocessorutil.automapped import auto_map


@auto_map({"system_api_key": {"name": "X-Api-Key", "location": "header", "type": str},
           "pos_id": {"name": "posId", "type": str},
           "payment_id": {"name": "paymentId", "type": int},
           "amount": {"name": "amount", "type": float}})
class OrderInsertPaymentRequest(object):
    def __init__(self, system_api_key, pos_id, payment_id, amount):
        # type: (str, str, int, float) -> None

        self.system_api_key = system_api_key
        self.pos_id = pos_id
        self.payment_id = payment_id
        self.amount = amount
